"""Give users direct access to methods."""
from b3u.b3u import\
    cred, credentials,\
    conf, configuration,\
    for_client, for_get
